@@ -287,19 +287,6 @@ class UserGroupsResource(ks_flask.ResourceBase):
     get_member_from_driver = PROVIDERS.deferred_provider_lookup(
         api='identity_api', method='get_group')
 
-    @staticmethod
-    def _built_target_attr_enforcement():
-        ref = None
-        if flask.request.view_args:
-            try:
-                ref = {'user': PROVIDERS.identity_api.get_user(
-                    flask.request.view_args.get('user_id'))}
-            except ks_exception.NotFound:  # nosec
-                # Defer existence in the event the user doesn't exist, we'll
-                # check this later anyway.
-                pass
-        return ref
-
     def get(self, user_id):
         """Get groups for a user.
 
@@ -308,7 +295,7 @@ class UserGroupsResource(ks_flask.ResourceBase):
         filters = ('name',)
         hints = self.build_driver_hints(filters)
         ENFORCER.enforce_call(action='identity:list_groups_for_user',
-                              build_target=self._built_target_attr_enforcement,
+                              build_target=_build_user_target_enforcement,
                               filters=filters)
         refs = PROVIDERS.identity_api.list_groups_for_user(user_id=user_id,
                                                            hints=hints)
@@ -361,7 +348,10 @@ class UserOSEC2CredentialsResourceListCreate(_UserOSEC2CredBaseResource):
 
         POST /v3/users/{user_id}/credentials/OS-EC2
         """
-        ENFORCER.enforce_call(action='identity:ec2_create_credential')
+        target = {}
+        target['credential'] = {'user_id': user_id}
+        ENFORCER.enforce_call(action='identity:ec2_create_credential',
+                              target_attr=target)
         PROVIDERS.identity_api.get_user(user_id)
         tenant_id = self.request_body_json.get('tenant_id')
         PROVIDERS.resource_api.get_project(tenant_id)
@@ -545,7 +535,8 @@ class UserAppCredListCreateResource(ks_flask.ResourceBase):
         # secret is only exposed after create, it is not stored
         'secret',
         'links',
-        'unrestricted'
+        'unrestricted',
+        'access_rules'
     ])
 
     @staticmethod
@@ -568,25 +559,6 @@ class UserAppCredListCreateResource(ks_flask.ResourceBase):
                     role['name']))
         return roles
 
-    def _get_roles(self, app_cred_data, token):
-        if app_cred_data.get('roles'):
-            roles = self._normalize_role_list(app_cred_data['roles'])
-            # NOTE(cmurphy): The user is not allowed to add a role that is not
-            # in their token. This is to prevent trustees or application
-            # credential users from escallating their privileges to include
-            # additional roles that the trustor or application credential
-            # creator has assigned on the project.
-            token_roles = [r['id'] for r in token.roles]
-            for role in roles:
-                if role['id'] not in token_roles:
-                    detail = _('Cannot create an application credential with '
-                               'unassigned role')
-                    raise ks_exception.ApplicationCredentialValidationError(
-                        detail=detail)
-        else:
-            roles = token.roles
-        return roles
-
     def get(self, user_id):
         """List application credentials for user.
 
@@ -622,10 +594,21 @@ class UserAppCredListCreateResource(ks_flask.ResourceBase):
             app_cred_data['secret'] = self._generate_secret()
         app_cred_data['user_id'] = user_id
         app_cred_data['project_id'] = project_id
-        app_cred_data['roles'] = self._get_roles(app_cred_data, token)
+        app_cred_data['roles'] = self._normalize_role_list(
+            app_cred_data.get('roles', token.roles))
         if app_cred_data.get('expires_at'):
             app_cred_data['expires_at'] = utils.parse_expiration_date(
                 app_cred_data['expires_at'])
+        if app_cred_data.get('access_rules'):
+            for access_rule in app_cred_data['access_rules']:
+                # If user provides an access rule by ID, it will be looked up
+                # by ID. If user provides an access rule that is identical to
+                # an existing one, the ID generated here will be ignored and
+                # the pre-existing access rule will be used.
+                if 'id' not in access_rule:
+                    # Generate directly, rather than using _assign_unique_id,
+                    # so that there is no deep copy made
+                    access_rule['id'] = uuid.uuid4().hex
         app_cred_data = self._normalize_dict(app_cred_data)
         app_cred_api = PROVIDERS.application_credential_api
 
@@ -670,6 +653,57 @@ class UserAppCredGetDeleteResource(ks_flask.ResourceBase):
         return None, http_client.NO_CONTENT
 
 
+class UserAccessRuleListResource(ks_flask.ResourceBase):
+    collection_key = 'access_rules'
+    member_key = 'access_rule'
+
+    def get(self, user_id):
+        """List access rules for user.
+
+        GET/HEAD /v3/users/{user_id}/access_rules
+        """
+        filters = ('service', 'path', 'method',)
+        ENFORCER.enforce_call(action='identity:list_access_rules',
+                              filters=filters,
+                              build_target=_build_user_target_enforcement)
+        app_cred_api = PROVIDERS.application_credential_api
+        hints = self.build_driver_hints(filters)
+        refs = app_cred_api.list_access_rules_for_user(user_id, hints=hints)
+        hints = self.build_driver_hints(filters)
+        return self.wrap_collection(refs, hints=hints)
+
+
+class UserAccessRuleGetDeleteResource(ks_flask.ResourceBase):
+    collection_key = 'access_rules'
+    member_key = 'access_rule'
+
+    def get(self, user_id, access_rule_id):
+        """Get access rule resource.
+
+        GET/HEAD /v3/users/{user_id}/access_rules/{access_rule_id}
+        """
+        ENFORCER.enforce_call(
+            action='identity:get_access_rule',
+            build_target=_build_user_target_enforcement
+        )
+        ref = PROVIDERS.application_credential_api.get_access_rule(
+            access_rule_id)
+        return self.wrap_member(ref)
+
+    def delete(self, user_id, access_rule_id):
+        """Delete access rule resource.
+
+        DELETE /v3/users/{user_id}/access_rules/{access_rule_id}
+        """
+        ENFORCER.enforce_call(
+            action='identity:delete_access_rule',
+            build_target=_build_user_target_enforcement
+        )
+        PROVIDERS.application_credential_api.delete_access_rule(
+            access_rule_id, initiator=self.audit_initiator)
+        return None, http_client.NO_CONTENT
+
+
 class UserAPI(ks_flask.APIBase):
     _name = 'users'
     _import_name = __name__
@@ -779,6 +813,24 @@ class UserAPI(ks_flask.APIBase):
                 'user_id': json_home.Parameters.USER_ID,
                 'application_credential_id':
                     json_home.Parameters.APPLICATION_CRED_ID}
+        ),
+        ks_flask.construct_resource_map(
+            resource=UserAccessRuleListResource,
+            url='/users/<string:user_id>/access_rules',
+            resource_kwargs={},
+            rel='access_rules',
+            path_vars={'user_id': json_home.Parameters.USER_ID}
+        ),
+        ks_flask.construct_resource_map(
+            resource=UserAccessRuleGetDeleteResource,
+            url=('/users/<string:user_id>/access_rules/'
+                 '<string:access_rule_id>'),
+            resource_kwargs={},
+            rel='access_rule',
+            path_vars={
+                'user_id': json_home.Parameters.USER_ID,
+                'access_rule_id':
+                    json_home.Parameters.ACCESS_RULE_ID}
         )
     ]
 
