@@ -19,18 +19,16 @@ import os
 import migrate
 from migrate import exceptions
 from migrate.versioning import api as versioning_api
+from oslo_db import exception as db_exception
 from oslo_db.sqlalchemy import migration
 import six
 import sqlalchemy
 
 from keystone.common import sql
-import keystone.conf
 from keystone import exception
 from keystone.i18n import _
 
 
-CONF = keystone.conf.CONF
-
 USE_TRIGGERS = True
 
 LEGACY_REPO = 'migrate_repo'
@@ -56,6 +54,7 @@ class Repository(object):
         upgrade = True
         version = versioning_api._migrate_version(
             self.schema_, version, upgrade, err)
+        validate_upgrade_order(self.repo_name, target_repo_version=version)
         if not current_schema:
             current_schema = self.schema_
         changeset = current_schema.changeset(version)
@@ -127,29 +126,6 @@ def add_constraints(constraints):
             refcolumns=[constraint_def['ref_column']]).create()
 
 
-def rename_tables_with_constraints(renames, constraints, engine):
-    """Rename tables with foreign key constraints.
-
-    Tables are renamed after first removing constraints. The constraints are
-    replaced after the rename is complete.
-
-    This works on databases that don't support renaming tables that have
-    constraints on them (DB2).
-
-    `renames` is a dict, mapping {'to_table_name': from_table, ...}
-    """
-    if engine.name != 'sqlite':
-        # SQLite doesn't support constraints, so nothing to remove.
-        remove_constraints(constraints)
-
-    for to_table_name in renames:
-        from_table = renames[to_table_name]
-        from_table.rename(to_table_name)
-
-    if engine != 'sqlite':
-        add_constraints(constraints)
-
-
 def find_repo(repo_name):
     """Return the absolute path to the named repository."""
     path = os.path.abspath(os.path.join(
@@ -180,7 +156,7 @@ def _sync_repo(repo_name):
         # an exception that we can safely ignore
         try:
             migration.db_version_control(engine, abs_path)
-        except (migration.exception.DbMigrationError,
+        except (migration.exception.DBMigrationError,
                 exceptions.DatabaseAlreadyControlledError):  # nosec
             pass
         init_version = get_init_version(abs_path=abs_path)
@@ -215,7 +191,7 @@ def _assert_not_schema_downgrade(version=None):
         try:
             current_ver = int(six.text_type(get_db_version()))
             if int(version) < current_ver:
-                raise migration.exception.DbMigrationError(
+                raise migration.exception.DBMigrationError(
                     _("Unable to downgrade schema"))
         except exceptions.DatabaseNotControlledError:  # nosec
             # NOTE(morganfainberg): The database is not controlled, this action
@@ -253,10 +229,64 @@ def offline_sync_database_to_version(version=None):
         contract_schema()
 
 
-def get_db_version():
+def get_db_version(repo=LEGACY_REPO):
     with sql.session_for_read() as session:
+        repo = find_repo(repo)
         return migration.db_version(
-            session.get_bind(), find_repo(LEGACY_REPO), get_init_version())
+            session.get_bind(), repo, get_init_version(repo))
+
+
+def validate_upgrade_order(repo_name, target_repo_version=None):
+    """Validate the state of the migration repositories.
+
+    This is run before allowing the db_sync command to execute. Ensure the
+    upgrade step and version specified by the operator remains consistent with
+    the upgrade process. I.e. expand's version is greater or equal to
+    migrate's, migrate's version is greater or equal to contract's.
+
+    :param repo_name: The name of the repository that the user is trying to
+                      upgrade.
+    :param target_repo_version: The version to upgrade the repo. Otherwise, the
+                                version will be upgraded to the latest version
+                                available.
+    """
+    # Initialize a dict to have each key assigned a repo with their value being
+    # the repo that comes before.
+    db_sync_order = {DATA_MIGRATION_REPO: EXPAND_REPO,
+                     CONTRACT_REPO: DATA_MIGRATION_REPO}
+
+    if repo_name == LEGACY_REPO:
+        return
+    # If expand is being run, we validate that Legacy repo is at the maximum
+    # version before running the additional schema expansions.
+    elif repo_name == EXPAND_REPO:
+        abs_path = find_repo(LEGACY_REPO)
+        repo = migrate.versioning.repository.Repository(abs_path)
+        if int(repo.latest) != get_db_version():
+            raise db_exception.DBMigrationError(
+                'Your Legacy repo version is not up to date. Please refer to '
+                'https://docs.openstack.org/keystone/latest/admin/'
+                'identity-upgrading.html '
+                'to see the proper steps for rolling upgrades.')
+        return
+
+    # find the latest version that the current command will upgrade to if there
+    # wasn't a version specified for upgrade.
+    if not target_repo_version:
+        abs_path = find_repo(repo_name)
+        repo = migrate.versioning.repository.Repository(abs_path)
+        target_repo_version = int(repo.latest)
+
+    # get current version of the command that runs before the current command.
+    dependency_repo_version = get_db_version(repo=db_sync_order[repo_name])
+
+    if dependency_repo_version < target_repo_version:
+        raise db_exception.DBMigrationError(
+            'You are attempting to upgrade %s ahead of %s. Please refer to '
+            'https://docs.openstack.org/keystone/latest/admin/'
+            'identity-upgrading.html '
+            'to see the proper steps for rolling upgrades.' % (
+                repo_name, db_sync_order[repo_name]))
 
 
 def expand_schema():
@@ -269,6 +299,7 @@ def expand_schema():
     # Make sure all the legacy migrations are run before we run any new
     # expand migrations.
     _sync_common_repo(version=None)
+    validate_upgrade_order(EXPAND_REPO)
     _sync_repo(repo_name=EXPAND_REPO)
 
 
@@ -279,6 +310,7 @@ def migrate_data():
     schema has been expanded for the new release.
 
     """
+    validate_upgrade_order(DATA_MIGRATION_REPO)
     _sync_repo(repo_name=DATA_MIGRATION_REPO)
 
 
@@ -290,4 +322,5 @@ def contract_schema():
     tables/columns that are no longer required.
 
     """
+    validate_upgrade_order(CONTRACT_REPO)
     _sync_repo(repo_name=CONTRACT_REPO)
