@@ -13,10 +13,11 @@
 import copy
 import datetime
 import sqlalchemy
-import uuid
 
 from oslo_config import cfg
+from oslo_db import api as oslo_db_api
 
+from keystone.common import provider_api
 from keystone.common import sql
 from keystone import exception
 from keystone.identity.backends import base as identity_base
@@ -25,13 +26,21 @@ from keystone.identity.shadow_backends import base
 
 
 CONF = cfg.CONF
+PROVIDERS = provider_api.ProviderAPIs
 
 
 class ShadowUsers(base.ShadowUsersDriverBase):
     @sql.handle_conflicts(conflict_type='federated_user')
     def create_federated_user(self, domain_id, federated_dict, email=None):
+
+        local_entity = {'domain_id': domain_id,
+                        'local_id': federated_dict['unique_id'],
+                        'entity_type': 'user'}
+
+        public_id = PROVIDERS.id_generator_api.generate_public_ID(local_entity)
+
         user = {
-            'id': uuid.uuid4().hex,
+            'id': public_id,
             'domain_id': domain_id,
             'enabled': True
         }
@@ -143,10 +152,8 @@ class ShadowUsers(base.ShadowUsersDriverBase):
     def create_nonlocal_user(self, user_dict):
         new_user_dict = copy.deepcopy(user_dict)
         # remove local_user attributes from new_user_dict
-        keys_to_delete = ['name', 'password']
-        for key in keys_to_delete:
-            if key in new_user_dict:
-                del new_user_dict[key]
+        new_user_dict.pop('name', None)
+        new_user_dict.pop('password', None)
         # create nonlocal_user dict
         new_nonlocal_user_dict = {
             'name': user_dict['name']
@@ -160,6 +167,17 @@ class ShadowUsers(base.ShadowUsersDriverBase):
             session.add(new_user_ref)
             return identity_base.filter_user(new_user_ref.to_dict())
 
+    @oslo_db_api.wrap_db_retry(retry_on_deadlock=True)
+    def delete_user(self, user_id):
+        with sql.session_for_write() as session:
+            ref = self._get_user(session, user_id)
+
+            q = session.query(model.UserGroupMembership)
+            q = q.filter_by(user_id=user_id)
+            q.delete(False)
+
+            session.delete(ref)
+
     def get_user(self, user_id):
         with sql.session_for_read() as session:
             user_ref = self._get_user(session, user_id)
