@@ -1156,7 +1156,7 @@ class CadfNotificationsWrapperTestCase(test_v3.RestfulTestCase):
                     'typeURI': 'service/security/account/user',
                     'host': {'address': 'localhost'},
                     'id': 'openstack:0a90d95d-582c-4efb-9cbc-e2ca7ca9c341',
-                    'username': u'admin'
+                    'name': u'bccc2d9bfc2a46fd9e33bcf82f0b5c21'
                 },
                 'target': {
                     'typeURI': 'service/security/account/user',
@@ -1202,17 +1202,6 @@ class CadfNotificationsWrapperTestCase(test_v3.RestfulTestCase):
         self.assertEqual(self.user_id, initiator.id)
         self.assertEqual(self.user_id, initiator.user_id)
 
-    def test_initiator_always_contains_username(self):
-        # Clear notifications
-        while self._notifications:
-            self._notifications.pop()
-
-        self.get_scoped_token()
-        self.assertEqual(len(self._notifications), 1)
-        note = self._notifications.pop()
-        initiator = note['initiator']
-        self.assertEqual(self.user['name'], initiator.username)
-
     def test_v3_authenticate_user_name_and_domain_id(self):
         user_id = self.user_id
         user_name = self.user['name']
