@@ -19,6 +19,7 @@ from testtools import matchers
 
 from keystone.common import driver_hints
 from keystone.common import provider_api
+from keystone.common.resource_options import options as ro_opt
 import keystone.conf
 from keystone import exception
 from keystone.resource.backends import sql as resource_sql
@@ -1682,6 +1683,336 @@ class ResourceTests(object):
         )
         self.assertEqual(project_tag_ref, [])
 
+    def test_create_project_immutable(self):
+        project = unit.new_project_ref(
+            domain_id=CONF.identity.default_domain_id)
+        project['options'][ro_opt.IMMUTABLE_OPT.option_name] = True
+
+        p_created = PROVIDERS.resource_api.create_project(
+            project['id'], project)
+        project_via_manager = PROVIDERS.resource_api.get_project(project['id'])
+        self.assertTrue('options' in p_created)
+        self.assertTrue('options' in project_via_manager)
+        self.assertTrue(
+            project_via_manager['options'][ro_opt.IMMUTABLE_OPT.option_name])
+        self.assertTrue(
+            p_created['options'][ro_opt.IMMUTABLE_OPT.option_name])
+
+    def test_cannot_update_immutable_project(self):
+        project = unit.new_project_ref(
+            domain_id=CONF.identity.default_domain_id)
+        project['options'][ro_opt.IMMUTABLE_OPT.option_name] = True
+        PROVIDERS.resource_api.create_project(project['id'], project)
+
+        update_project = {'name': uuid.uuid4().hex}
+        self.assertRaises(exception.ResourceUpdateForbidden,
+                          PROVIDERS.resource_api.update_project,
+                          project['id'],
+                          update_project)
+
+    def test_cannot_update_immutable_project_while_unsetting_immutable(self):
+        project = unit.new_project_ref(
+            domain_id=CONF.identity.default_domain_id)
+        project['options'][ro_opt.IMMUTABLE_OPT.option_name] = True
+        PROVIDERS.resource_api.create_project(project['id'], project)
+
+        update_project = {
+            'name': uuid.uuid4().hex,
+            'options': {
+                ro_opt.IMMUTABLE_OPT.option_name: True
+            }}
+        self.assertRaises(exception.ResourceUpdateForbidden,
+                          PROVIDERS.resource_api.update_project,
+                          project['id'],
+                          update_project)
+
+    def test_cannot_delete_immutable_project(self):
+        project = unit.new_project_ref(
+            domain_id=CONF.identity.default_domain_id)
+        project['options'][ro_opt.IMMUTABLE_OPT.option_name] = True
+        PROVIDERS.resource_api.create_project(project['id'], project)
+        self.assertRaises(exception.ResourceDeleteForbidden,
+                          PROVIDERS.resource_api.delete_project,
+                          project['id'])
+
+    def test_update_project_set_immutable(self):
+        project = unit.new_project_ref(
+            domain_id=CONF.identity.default_domain_id)
+        PROVIDERS.resource_api.create_project(project['id'], project)
+        update_project = {
+            'options': {
+                ro_opt.IMMUTABLE_OPT.option_name: True
+            }}
+        project_via_manager = PROVIDERS.resource_api.get_project(project['id'])
+        self.assertTrue('options' in project_via_manager)
+        self.assertFalse(
+            ro_opt.IMMUTABLE_OPT.option_name in project_via_manager['options'])
+        p_update = PROVIDERS.resource_api.update_project(
+            project['id'], update_project)
+        project_via_manager = PROVIDERS.resource_api.get_project(project['id'])
+        self.assertTrue(
+            ro_opt.IMMUTABLE_OPT.option_name in p_update['options'])
+        self.assertTrue(
+            p_update['options'][ro_opt.IMMUTABLE_OPT.option_name])
+        self.assertTrue(
+            ro_opt.IMMUTABLE_OPT.option_name in project_via_manager['options'])
+        self.assertTrue(
+            project_via_manager['options'][ro_opt.IMMUTABLE_OPT.option_name])
+
+    def test_update_project_set_immutable_with_additional_updates(self):
+        project = unit.new_project_ref(
+            domain_id=CONF.identity.default_domain_id)
+        PROVIDERS.resource_api.create_project(project['id'], project)
+        update_project = {
+            'name': uuid.uuid4().hex,
+            'options': {
+                ro_opt.IMMUTABLE_OPT.option_name: True
+            }}
+        project_via_manager = PROVIDERS.resource_api.get_project(project['id'])
+        self.assertTrue('options' in project_via_manager)
+        self.assertFalse(
+            ro_opt.IMMUTABLE_OPT.option_name in project_via_manager['options'])
+        p_update = PROVIDERS.resource_api.update_project(
+            project['id'], update_project)
+        project_via_manager = PROVIDERS.resource_api.get_project(project['id'])
+        self.assertEqual(p_update['name'], update_project['name'])
+        self.assertEqual(project_via_manager['name'], update_project['name'])
+        self.assertTrue(
+            ro_opt.IMMUTABLE_OPT.option_name in p_update['options'])
+        self.assertTrue(
+            p_update['options'][ro_opt.IMMUTABLE_OPT.option_name])
+        self.assertTrue(
+            ro_opt.IMMUTABLE_OPT.option_name in project_via_manager['options'])
+        self.assertTrue(
+            project_via_manager['options'][ro_opt.IMMUTABLE_OPT.option_name])
+
+    def test_update_project_unset_immutable(self):
+        project = unit.new_project_ref(
+            domain_id=CONF.identity.default_domain_id)
+        project['options'][ro_opt.IMMUTABLE_OPT.option_name] = True
+        PROVIDERS.resource_api.create_project(project['id'], project)
+        project_via_manager = PROVIDERS.resource_api.get_project(project['id'])
+        self.assertTrue('options' in project_via_manager)
+        self.assertTrue(
+            project_via_manager['options'][ro_opt.IMMUTABLE_OPT.option_name])
+
+        update_project = {
+            'options': {
+                ro_opt.IMMUTABLE_OPT.option_name: False
+            }}
+        PROVIDERS.resource_api.update_project(project['id'], update_project)
+        project_via_manager = PROVIDERS.resource_api.get_project(project['id'])
+        self.assertTrue('options' in project_via_manager)
+        self.assertTrue(
+            ro_opt.IMMUTABLE_OPT.option_name in project_via_manager['options'])
+        self.assertFalse(
+            project_via_manager['options'][ro_opt.IMMUTABLE_OPT.option_name])
+
+        update_project = {'name': uuid.uuid4().hex}
+        p_updated = PROVIDERS.resource_api.update_project(
+            project['id'], update_project)
+        self.assertEqual(p_updated['name'], update_project['name'])
+
+        update_project = {
+            'options': {
+                ro_opt.IMMUTABLE_OPT.option_name: None
+            }}
+        p_updated = PROVIDERS.resource_api.update_project(
+            project['id'], update_project)
+        project_via_manager = PROVIDERS.resource_api.get_project(project['id'])
+        self.assertTrue('options' in p_updated)
+        self.assertTrue('options' in project_via_manager)
+        self.assertFalse(
+            ro_opt.IMMUTABLE_OPT.option_name in p_updated['options'])
+        self.assertFalse(
+            ro_opt.IMMUTABLE_OPT.option_name in project_via_manager['options'])
+
+    def test_cannot_delete_project_tags_immutable_project(self):
+        project, tags = self._create_project_and_tags(num_of_tags=2)
+        update_project = {
+            'options': {
+                ro_opt.IMMUTABLE_OPT.option_name: True
+            }
+        }
+        PROVIDERS.resource_api.update_project(project['id'], update_project)
+        self.assertRaises(exception.ResourceUpdateForbidden,
+                          PROVIDERS.resource_api.delete_project_tag,
+                          project['id'],
+                          tags[0])
+
+    def test_cannot_update_project_tags_immutable_project(self):
+        # Update and Add tag use the same API
+        project, tags = self._create_project_and_tags(num_of_tags=2)
+        update_project = {
+            'options': {
+                ro_opt.IMMUTABLE_OPT.option_name: True
+            }
+        }
+        PROVIDERS.resource_api.update_project(project['id'], update_project)
+        tags.append(uuid.uuid4().hex)
+        self.assertRaises(exception.ResourceUpdateForbidden,
+                          PROVIDERS.resource_api.update_project_tags,
+                          project['id'],
+                          tags)
+
+    @unit.skip_if_no_multiple_domains_support
+    def test_create_domain_immutable(self):
+        domain_id = uuid.uuid4().hex
+
+        domain = {
+            'name': uuid.uuid4().hex,
+            'id': domain_id,
+            'is_domain': True,
+            'options': {'immutable': True}
+        }
+
+        PROVIDERS.resource_api.create_domain(domain_id, domain)
+        domain_via_manager = PROVIDERS.resource_api.get_domain(domain_id)
+        self.assertTrue('options' in domain_via_manager)
+        self.assertTrue(domain_via_manager['options']['immutable'])
+
+    @unit.skip_if_no_multiple_domains_support
+    def test_cannot_update_immutable_domain(self):
+        domain_id = uuid.uuid4().hex
+
+        domain = {
+            'name': uuid.uuid4().hex,
+            'id': domain_id,
+            'is_domain': True,
+            'options': {'immutable': True}
+        }
+
+        PROVIDERS.resource_api.create_domain(domain_id, domain)
+        update_domain = {'name': uuid.uuid4().hex}
+        self.assertRaises(exception.ResourceUpdateForbidden,
+                          PROVIDERS.resource_api.update_domain,
+                          domain_id,
+                          update_domain)
+
+    @unit.skip_if_no_multiple_domains_support
+    def test_cannot_delete_immutable_domain(self):
+        domain_id = uuid.uuid4().hex
+
+        domain = {
+            'name': uuid.uuid4().hex,
+            'id': domain_id,
+            'is_domain': True,
+            'options': {'immutable': True}
+        }
+
+        PROVIDERS.resource_api.create_domain(domain_id, domain)
+        self.assertRaises(exception.ResourceDeleteForbidden,
+                          PROVIDERS.resource_api.delete_domain,
+                          domain_id,)
+
+    @unit.skip_if_no_multiple_domains_support
+    def test_cannot_delete_disabled_domain_with_immutable_project(self):
+        domain_id = uuid.uuid4().hex
+
+        domain = {
+            'name': uuid.uuid4().hex,
+            'id': domain_id,
+            'is_domain': True,
+        }
+
+        PROVIDERS.resource_api.create_domain(domain_id, domain)
+        project = unit.new_project_ref(domain_id)
+        project['options'][ro_opt.IMMUTABLE_OPT.option_name] = True
+        PROVIDERS.resource_api.create_project(project['id'], project)
+        # Disable the domain
+        PROVIDERS.resource_api.update_domain(domain_id, {'enabled': False})
+        # attempt to delete the domain, should error when the immutable
+        # project is reached
+        self.assertRaises(exception.ResourceDeleteForbidden,
+                          PROVIDERS.resource_api.delete_domain,
+                          domain_id)
+
+    @unit.skip_if_no_multiple_domains_support
+    def test_update_domain_set_immutable(self):
+        # domains are projects, this should be the same as the project version
+        domain_id = uuid.uuid4().hex
+
+        domain = {
+            'name': uuid.uuid4().hex,
+            'id': domain_id,
+            'is_domain': True,
+        }
+
+        PROVIDERS.resource_api.create_domain(domain_id, domain)
+        domain_via_manager = PROVIDERS.resource_api.get_domain(domain_id)
+        self.assertTrue('options' in domain_via_manager)
+        self.assertFalse(
+            ro_opt.IMMUTABLE_OPT.option_name in domain_via_manager['options'])
+
+        domain_update = {
+            'options': {
+                ro_opt.IMMUTABLE_OPT.option_name: True
+            }}
+        d_update = PROVIDERS.resource_api.update_domain(
+            domain_id, domain_update)
+        domain_via_manager = PROVIDERS.resource_api.get_domain(domain_id)
+        self.assertTrue(
+            ro_opt.IMMUTABLE_OPT.option_name in d_update['options'])
+        self.assertTrue(
+            d_update['options'][ro_opt.IMMUTABLE_OPT.option_name])
+        self.assertTrue(
+            ro_opt.IMMUTABLE_OPT.option_name in domain_via_manager['options'])
+        self.assertTrue(
+            domain_via_manager['options'][ro_opt.IMMUTABLE_OPT.option_name])
+
+    def test_update_domain_unset_immutable(self):
+        # domains are projects, this should be the same as the project version
+        domain_id = uuid.uuid4().hex
+
+        domain = {
+            'name': uuid.uuid4().hex,
+            'id': domain_id,
+            'is_domain': True,
+        }
+
+        PROVIDERS.resource_api.create_domain(domain_id, domain)
+        domain_via_manager = PROVIDERS.resource_api.get_domain(domain_id)
+        self.assertTrue('options' in domain_via_manager)
+        self.assertFalse(
+            ro_opt.IMMUTABLE_OPT.option_name in domain_via_manager['options'])
+
+        update_domain = {
+            'options': {
+                ro_opt.IMMUTABLE_OPT.option_name: False
+            }}
+        d_updated = PROVIDERS.resource_api.update_domain(
+            domain_id, update_domain)
+        domain_via_manager = PROVIDERS.resource_api.get_domain(domain_id)
+        self.assertTrue('options' in domain_via_manager)
+        self.assertTrue('options' in d_updated)
+        self.assertTrue(
+            ro_opt.IMMUTABLE_OPT.option_name in domain_via_manager['options'])
+        self.assertTrue(
+            ro_opt.IMMUTABLE_OPT.option_name in d_updated['options'])
+        self.assertFalse(
+            d_updated['options'][ro_opt.IMMUTABLE_OPT.option_name])
+        self.assertFalse(
+            domain_via_manager['options'][ro_opt.IMMUTABLE_OPT.option_name])
+
+        update_domain = {'name': uuid.uuid4().hex}
+        d_updated = PROVIDERS.resource_api.update_domain(
+            domain_id, update_domain)
+        self.assertEqual(d_updated['name'], update_domain['name'])
+
+        update_domain = {
+            'options': {
+                ro_opt.IMMUTABLE_OPT.option_name: None
+            }}
+        d_updated = PROVIDERS.resource_api.update_domain(
+            domain_id, update_domain)
+        domain_via_manager = PROVIDERS.resource_api.get_domain(domain_id)
+        self.assertTrue('options' in d_updated)
+        self.assertTrue('options' in domain_via_manager)
+        self.assertFalse(
+            ro_opt.IMMUTABLE_OPT.option_name in d_updated['options'])
+        self.assertFalse(
+            ro_opt.IMMUTABLE_OPT.option_name in domain_via_manager['options'])
+
 
 class ResourceDriverTests(object):
     """Test for the resource driver.
