@@ -53,6 +53,7 @@ class RestfulTestCase(unit.SQLDriverOverrides, rest.RestfulTestCase,
                     'id': {'type': 'string', },
                     'name': {'type': 'string', },
                     'description': {'type': 'string', },
+                    'options': {'type': 'object', }
                 },
                 'required': ['id', 'name', ],
                 'additionalProperties': False,
@@ -1401,8 +1402,6 @@ class AssignmentTestMixin(object):
         """
         if attribs.get('domain_id'):
             link = '/domains/' + attribs['domain_id']
-        elif attribs.get('system'):
-            link = '/system'
         else:
             link = '/projects/' + attribs['project_id']
 
@@ -1430,8 +1429,6 @@ class AssignmentTestMixin(object):
 
         if attribs.get('domain_id'):
             entity['scope'] = {'domain': {'id': attribs['domain_id']}}
-        elif attribs.get('system'):
-            entity['scope'] = {'system': {'all': True}}
         else:
             entity['scope'] = {'project': {'id': attribs['project_id']}}
 
