@@ -35,7 +35,8 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
         self.config_fixture.config(group='auth',
                                    methods='password,application_credential')
 
-    def _app_cred_body(self, roles=None, name=None, expires=None, secret=None):
+    def _app_cred_body(self, roles=None, name=None, expires=None, secret=None,
+                       access_rules=None):
         name = name or uuid.uuid4().hex
         description = 'Credential for backups'
         app_cred_data = {
@@ -48,6 +49,8 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
             app_cred_data['expires_at'] = expires
         if secret:
             app_cred_data['secret'] = secret
+        if access_rules is not None:
+            app_cred_data['access_rules'] = access_rules
         return {'application_credential': app_cred_data}
 
     def test_create_application_credential(self):
@@ -166,37 +169,6 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
                    expected_status_code=http_client.FORBIDDEN,
                    headers={'X-Auth-Token': token})
 
-    def test_create_application_credential_with_trust(self):
-        second_role = unit.new_role_ref(name='reader')
-        PROVIDERS.role_api.create_role(second_role['id'], second_role)
-        PROVIDERS.assignment_api.add_role_to_user_and_project(
-            self.user_id, self.project_id, second_role['id'])
-        with self.test_client() as c:
-            pw_token = self.get_scoped_token()
-            # create a self-trust - only the roles are important for this test
-            trust_ref = unit.new_trust_ref(
-                trustor_user_id=self.user_id,
-                trustee_user_id=self.user_id,
-                project_id=self.project_id,
-                role_ids=[second_role['id']])
-            resp = c.post('/v3/OS-TRUST/trusts',
-                          headers={'X-Auth-Token': pw_token},
-                          json={'trust': trust_ref})
-            trust_id = resp.json['trust']['id']
-            trust_auth = self.build_authentication_request(
-                user_id=self.user_id,
-                password=self.user['password'],
-                trust_id=trust_id)
-            trust_token = self.v3_create_token(
-                trust_auth).headers['X-Subject-Token']
-            app_cred = self._app_cred_body(roles=[{'id': self.role_id}])
-            # only the roles from the trust token should be allowed, even if
-            # the user has the role assigned on the project
-            c.post('/v3/users/%s/application_credentials' % self.user_id,
-                   headers={'X-Auth-Token': trust_token},
-                   json=app_cred,
-                   expected_status_code=http_client.BAD_REQUEST)
-
     def test_create_application_credential_allow_recursion(self):
         with self.test_client() as c:
             roles = [{'id': self.role_id}]
@@ -218,6 +190,119 @@ class ApplicationCredentialTestCase(test_v3.RestfulTestCase):
                    expected_status_code=http_client.CREATED,
                    headers={'x-Auth-Token': token_data.headers['x-subject-token']})
 
+    def test_create_application_credential_with_access_rules(self):
+        roles = [{'id': self.role_id}]
+        access_rules = [
+            {
+                'path': '/v3/projects',
+                'method': 'POST',
+                'service': 'identity',
+            }
+        ]
+        app_cred_body = self._app_cred_body(roles=roles,
+                                            access_rules=access_rules)
+        with self.test_client() as c:
+            token = self.get_scoped_token()
+            resp = c.post('/v3/users/%s/application_credentials' % self.user_id,
+                          headers={'X-Auth-Token': token},
+                          json=app_cred_body,
+                          expected_status_code=http_client.CREATED)
+            app_cred_id = resp.json['application_credential']['id']
+            resp_access_rules = resp.json['application_credential']['access_rules']
+            access_rule_id = resp_access_rules[0].pop('id')
+            self.assertEqual(access_rules[0], resp_access_rules[0])
+            resp = c.get('/v3/users/%s/access_rules' % self.user_id,
+                         headers={'X-Auth-Token': token})
+            resp_access_rule = resp.json['access_rules'][0]
+            resp_access_rule.pop('id')
+            resp_access_rule.pop('links')
+            self.assertEqual(access_rules[0], resp_access_rule)
+            resp = c.get('/v3/users/%s/access_rules/%s' % (
+                self.user_id, access_rule_id), headers={'X-Auth-Token': token})
+            resp_access_rule = resp.json['access_rule']
+            resp_access_rule.pop('id')
+            resp_access_rule.pop('links')
+            self.assertEqual(access_rules[0], resp_access_rule)
+            # can't delete an access rule in use
+            c.delete('/v3/users/%s/access_rules/%s' % (
+                     self.user_id, access_rule_id),
+                     headers={'X-Auth-Token': token},
+                     expected_status_code=http_client.FORBIDDEN)
+            c.delete('/v3/users/%s/application_credentials/%s' % (
+                     self.user_id, app_cred_id),
+                     headers={'X-Auth-Token': token})
+            c.delete('/v3/users/%s/access_rules/%s' % (
+                     self.user_id, access_rule_id),
+                     headers={'X-Auth-Token': token})
+
+    def test_create_application_credential_with_duplicate_access_rule(self):
+        roles = [{'id': self.role_id}]
+        access_rules = [
+            {
+                'path': '/v3/projects',
+                'method': 'POST',
+                'service': 'identity',
+            }
+        ]
+        app_cred_body_1 = self._app_cred_body(roles=roles,
+                                              access_rules=access_rules)
+        with self.test_client() as c:
+            token = self.get_scoped_token()
+            resp = c.post('/v3/users/%s/application_credentials' % self.user_id,
+                          headers={'X-Auth-Token': token},
+                          json=app_cred_body_1,
+                          expected_status_code=http_client.CREATED)
+        resp_access_rules = resp.json['application_credential']['access_rules']
+        self.assertIn('id', resp_access_rules[0])
+        access_rule_id = resp_access_rules[0].pop('id')
+        self.assertEqual(access_rules[0], resp_access_rules[0])
+
+        app_cred_body_2 = self._app_cred_body(roles=roles,
+                                              access_rules=access_rules)
+        with self.test_client() as c:
+            token = self.get_scoped_token()
+            resp = c.post('/v3/users/%s/application_credentials' % self.user_id,
+                          headers={'X-Auth-Token': token},
+                          json=app_cred_body_2,
+                          expected_status_code=http_client.CREATED)
+        resp_access_rules = resp.json['application_credential']['access_rules']
+        self.assertEqual(access_rule_id, resp_access_rules[0]['id'])
+
+    def test_create_application_credential_with_access_rule_by_id(self):
+        roles = [{'id': self.role_id}]
+        access_rules = [
+            {
+                'path': '/v3/projects',
+                'method': 'POST',
+                'service': 'identity',
+            }
+        ]
+        app_cred_body_1 = self._app_cred_body(roles=roles,
+                                              access_rules=access_rules)
+        with self.test_client() as c:
+            token = self.get_scoped_token()
+            resp = c.post('/v3/users/%s/application_credentials' % self.user_id,
+                          headers={'X-Auth-Token': token},
+                          json=app_cred_body_1,
+                          expected_status_code=http_client.CREATED)
+        resp_access_rules = resp.json['application_credential']['access_rules']
+        access_rule_id = resp_access_rules
+        self.assertIn('id', resp_access_rules[0])
+        access_rule_id = resp_access_rules[0].pop('id')
+        self.assertEqual(access_rules[0], resp_access_rules[0])
+
+        access_rules = [{'id': access_rule_id}]
+        app_cred_body_2 = self._app_cred_body(roles=roles,
+                                              access_rules=access_rules)
+        with self.test_client() as c:
+            token = self.get_scoped_token()
+            resp = c.post('/v3/users/%s/application_credentials' % self.user_id,
+                          headers={'X-Auth-Token': token},
+                          json=app_cred_body_2,
+                          expected_status_code=http_client.CREATED)
+        resp_access_rules = resp.json['application_credential']['access_rules']
+        self.assertEqual(access_rule_id, resp_access_rules[0]['id'])
+
     def test_list_application_credentials(self):
         with self.test_client() as c:
             token = self.get_scoped_token()
