@@ -643,12 +643,6 @@ class IdentityTestv3CloudPolicySample(test_v3.RestfulTestCase,
                                       test_v3.AssignmentTestMixin):
     """Test policy enforcement of the sample v3 cloud policy file."""
 
-    def _policy_fixture(self):
-        return ksfixtures.Policy(
-            self.config_fixture,
-            policy_file=unit.dirs.etc('policy.v3cloudsample.json')
-        )
-
     def setUp(self):
         """Setup for v3 Cloud Policy Sample Test Cases.
 
@@ -964,28 +958,6 @@ class IdentityTestv3CloudPolicySample(test_v3.RestfulTestCase,
         # other than its own domain or not
         self._test_project_management(self.domainA['id'])
 
-    def test_domain_grants(self):
-        self.auth = self.build_authentication_request(
-            user_id=self.just_a_user['id'],
-            password=self.just_a_user['password'],
-            domain_id=self.domainA['id'])
-
-        self._test_grants('domains', self.domainA['id'],
-                          expected=exception.ForbiddenAction.code)
-
-        # Now, authenticate with a user that does have the domain admin role
-        self.auth = self.build_authentication_request(
-            user_id=self.domain_admin_user['id'],
-            password=self.domain_admin_user['password'],
-            domain_id=self.domainA['id'])
-
-        self._test_grants('domains', self.domainA['id'])
-
-        # Check that with such a token we cannot modify grants on a
-        # different domain
-        self._test_grants('domains', self.domainB['id'],
-                          expected=exception.ForbiddenAction.code)
-
     def test_domain_grants_by_cloud_admin(self):
         # Test domain grants with a cloud admin. This user should be
         # able to manage roles on any domain.
@@ -1021,27 +993,6 @@ class IdentityTestv3CloudPolicySample(test_v3.RestfulTestCase,
                           role_domain_id=self.domainB['id'],
                           expected=exception.ForbiddenAction.code)
 
-    def test_domain_grants_by_domain_admin_for_domain_specific_role(self):
-        # Authenticate with a user that does have the domain admin role,
-        # should not be able to assign a domain_specific role from another
-        # domain
-        self.auth = self.build_authentication_request(
-            user_id=self.domain_admin_user['id'],
-            password=self.domain_admin_user['password'],
-            domain_id=self.domainA['id'])
-
-        self._test_grants('domains', self.domainA['id'],
-                          role_domain_id=self.domainB['id'],
-                          # List status will always be OK, since we are not
-                          # granting/checking/deleting assignments
-                          list_status_OK=True,
-                          expected=exception.ForbiddenAction.code)
-
-        # They should be able to assign a domain specific role from the same
-        # domain
-        self._test_grants('domains', self.domainA['id'],
-                          role_domain_id=self.domainA['id'])
-
     def test_project_grants(self):
         self.auth = self.build_authentication_request(
             user_id=self.just_a_user['id'],
@@ -1084,48 +1035,6 @@ class IdentityTestv3CloudPolicySample(test_v3.RestfulTestCase,
                           role_domain_id=self.domainB['id'],
                           expected=exception.ForbiddenAction.code)
 
-    def test_project_grants_by_project_admin_for_domain_specific_role(self):
-        # Authenticate with a user that does have the project admin role,
-        # should not be able to assign a domain_specific role from another
-        # domain
-        self.auth = self.build_authentication_request(
-            user_id=self.project_admin_user['id'],
-            password=self.project_admin_user['password'],
-            project_id=self.project['id'])
-
-        self._test_grants('projects', self.project['id'],
-                          role_domain_id=self.domainB['id'],
-                          # List status will always be OK, since we are not
-                          # granting/checking/deleting assignments
-                          list_status_OK=True,
-                          expected=exception.ForbiddenAction.code)
-
-        # They should be able to assign a domain specific role from the same
-        # domain
-        self._test_grants('projects', self.project['id'],
-                          role_domain_id=self.domainA['id'])
-
-    def test_project_grants_by_domain_admin_for_domain_specific_role(self):
-        # Authenticate with a user that does have the domain admin role,
-        # should not be able to assign a domain_specific role from another
-        # domain
-        self.auth = self.build_authentication_request(
-            user_id=self.domain_admin_user['id'],
-            password=self.domain_admin_user['password'],
-            domain_id=self.domainA['id'])
-
-        self._test_grants('projects', self.project['id'],
-                          role_domain_id=self.domainB['id'],
-                          # List status will always be OK, since we are not
-                          # granting/checking/deleting assignments
-                          list_status_OK=True,
-                          expected=exception.ForbiddenAction.code)
-
-        # They should be able to assign a domain specific role from the same
-        # domain
-        self._test_grants('projects', self.project['id'],
-                          role_domain_id=self.domainA['id'])
-
     def test_cloud_admin_list_assignments_of_domain(self):
         self.auth = self.build_authentication_request(
             user_id=self.cloud_admin_user['id'],
@@ -1252,55 +1161,6 @@ class IdentityTestv3CloudPolicySample(test_v3.RestfulTestCase,
         self.assertRoleAssignmentInListResponse(r, project_admin_entity)
         self.assertRoleAssignmentInListResponse(r, project_user_entity)
 
-    def test_domain_admin_list_assignment_tree(self):
-        # Add a child project to the standard test data
-        sub_project = unit.new_project_ref(domain_id=self.domainA['id'],
-                                           parent_id=self.project['id'])
-        PROVIDERS.resource_api.create_project(sub_project['id'], sub_project)
-        PROVIDERS.assignment_api.create_grant(
-            self.role['id'], user_id=self.just_a_user['id'],
-            project_id=sub_project['id']
-        )
-
-        collection_url = self.build_role_assignment_query_url(
-            project_id=self.project['id'])
-        collection_url += '&include_subtree=True'
-
-        # The domain admin should be able to list the assignment tree
-        auth = self.build_authentication_request(
-            user_id=self.domain_admin_user['id'],
-            password=self.domain_admin_user['password'],
-            domain_id=self.domainA['id'])
-
-        r = self.get(collection_url, auth=auth)
-        self.assertValidRoleAssignmentListResponse(
-            r, expected_length=3, resource_url=collection_url)
-
-        # A project admin should not be able to
-        auth = self.build_authentication_request(
-            user_id=self.project_admin_user['id'],
-            password=self.project_admin_user['password'],
-            project_id=self.project['id'])
-
-        r = self.get(collection_url, auth=auth,
-                     expected_status=http_client.FORBIDDEN)
-
-        # A neither should a domain admin from a different domain
-        domainB_admin_user = unit.create_user(
-            PROVIDERS.identity_api,
-            domain_id=self.domainB['id'])
-        PROVIDERS.assignment_api.create_grant(
-            self.admin_role['id'], user_id=domainB_admin_user['id'],
-            domain_id=self.domainB['id']
-        )
-        auth = self.build_authentication_request(
-            user_id=domainB_admin_user['id'],
-            password=domainB_admin_user['password'],
-            domain_id=self.domainB['id'])
-
-        r = self.get(collection_url, auth=auth,
-                     expected_status=http_client.FORBIDDEN)
-
     def test_domain_user_list_assignments_of_project_failed(self):
         self.auth = self.build_authentication_request(
             user_id=self.just_a_user['id'],
@@ -1633,78 +1493,6 @@ class IdentityTestv3CloudPolicySample(test_v3.RestfulTestCase,
 
         self._role_management_cases()
 
-    def test_domain_role_management_no_admin_no_rights(self):
-        # A non-admin domain user shouldn't be able to manipulate domain roles
-        self.auth = self.build_authentication_request(
-            user_id=self.just_a_user['id'],
-            password=self.just_a_user['password'],
-            domain_id=self.domainA['id'])
-
-        self._domain_role_management_cases(
-            self.domainA['id'], expected=exception.ForbiddenAction.code)
-
-        # ...and nor should non-admin project user
-        self.auth = self.build_authentication_request(
-            user_id=self.just_a_user['id'],
-            password=self.just_a_user['password'],
-            project_id=self.project['id'])
-
-        self._domain_role_management_cases(
-            self.domainA['id'], expected=exception.ForbiddenAction.code)
-
-    def test_domain_role_management_with_cloud_admin(self):
-        # A cloud admin user should have rights to manipulate domain roles
-        self.auth = self.build_authentication_request(
-            user_id=self.cloud_admin_user['id'],
-            password=self.cloud_admin_user['password'],
-            project_id=self.admin_project['id'])
-
-        self._domain_role_management_cases(self.domainA['id'])
-
-    def test_domain_role_management_with_domain_admin(self):
-        # A domain admin user should only be able to manipulate the domain
-        # specific roles in their own domain
-        self.auth = self.build_authentication_request(
-            user_id=self.domainB_admin_user['id'],
-            password=self.domainB_admin_user['password'],
-            domain_id=self.domainB['id'])
-
-        # Try to access the domain specific roles in another domain
-        self._domain_role_management_cases(
-            self.domainA['id'], expected=exception.ForbiddenAction.code)
-
-        # ...but they should be able to work with those in their own domain
-        self.auth = self.build_authentication_request(
-            user_id=self.domain_admin_user['id'],
-            password=self.domain_admin_user['password'],
-            domain_id=self.domainA['id'])
-
-        self._domain_role_management_cases(self.domainA['id'])
-
-    def test_domain_role_management_with_project_admin(self):
-        # A project admin user should have not access to domain specific roles
-        # in another domain. They should be able to get and list domain
-        # specific roles from their own domain, but not be able to create,
-        # update or delete them,
-        self.auth = self.build_authentication_request(
-            user_id=self.project_adminB_user['id'],
-            password=self.project_adminB_user['password'],
-            project_id=self.projectB['id'])
-
-        # Try access the domain specific roless in another domain
-        self._domain_role_management_cases(
-            self.domainA['id'], expected=exception.ForbiddenAction.code)
-
-        # ...but they should be ablet to work with those in their own domain
-        self.auth = self.build_authentication_request(
-            user_id=self.project_admin_user['id'],
-            password=self.project_admin_user['password'],
-            project_id=self.project['id'])
-
-        self._domain_role_management_cases(
-            self.domainA['id'], read_status_OK=True,
-            expected=exception.ForbiddenAction.code)
-
 
 class IdentityTestImpliedDomainSpecificRoles(IdentityTestv3CloudPolicySample):
     """Test Domain specific Implied Roles via the REST API."""
@@ -1775,32 +1563,3 @@ class IdentityTestImpliedDomainSpecificRoles(IdentityTestv3CloudPolicySample):
         self.delete('/roles/%s/implies/%s'
                     % (self.appadmin_role['id'], self.appdev_role['id']),
                     token=self.admin_token)
-
-    def test_forbidden_role_implication_from_different_domain(self):
-        domain2 = unit.new_domain_ref(domain_id=uuid.uuid4().hex)
-        PROVIDERS.resource_api.create_domain(domain2['id'], domain2)
-
-        role2 = unit.new_role_ref(domain_id=domain2['id'])
-        implied = PROVIDERS.role_api.create_role(role2['id'], role2)
-
-        self.put('/roles/%s/implies/%s'
-                 % (self.appdev_role['id'], implied['id']),
-                 token=self.admin_token,
-                 expected_status=http_client.FORBIDDEN)
-
-    def test_allowed_role_implication_different_domains_as_cloud_admin(self):
-        self.auth = self.build_authentication_request(
-            user_id=self.cloud_admin_user['id'],
-            password=self.cloud_admin_user['password'],
-            project_id=self.admin_project['id'])
-
-        domain2 = unit.new_domain_ref(domain_id=uuid.uuid4().hex)
-        PROVIDERS.resource_api.create_domain(domain2['id'], domain2)
-
-        role2 = unit.new_role_ref(domain_id=domain2['id'])
-        implied = PROVIDERS.role_api.create_role(role2['id'], role2)
-
-        self.put('/roles/%s/implies/%s'
-                 % (self.appdev_role['id'], implied['id']),
-                 auth=self.auth,
-                 expected_status=http_client.CREATED)
